@@ -20,12 +20,19 @@ from . import ospath as path
 
 stat = wrap(os.stat)
 rename = wrap(os.rename)
+renames = wrap(os.renames)
 replace = wrap(os.replace)
 remove = wrap(os.remove)
+unlink = wrap(os.unlink)
 mkdir = wrap(os.mkdir)
 makedirs = wrap(os.makedirs)
 rmdir = wrap(os.rmdir)
 removedirs = wrap(os.removedirs)
+link = wrap(os.link)
+symlink = wrap(os.symlink)
+readlink = wrap(os.readlink)
+listdir = wrap(os.listdir)
+scandir = wrap(os.scandir)
 
 if hasattr(os, "sendfile"):
     sendfile = wrap(os.sendfile)
